@@ -1,4 +1,6 @@
 from .alacritty import Alacritty
+from .bash import Bash
+from .gimp import Gimp
 from .lf import Lf
 from .mpv import Mpv
 from .neovim import Neovim
@@ -15,6 +17,8 @@ from .zsh import Zsh
 
 __all__ = [
     "Alacritty",
+    "Bash",
+    "Gimp",
     "Lf",
     "Mpv",
     "Neovim",
