@@ -8,9 +8,11 @@ class Vimiv(Parser):
     has_modes = True
 
     def fetch(self) -> HotkeysWithModes:
-        from vimiv import api
+        from vimiv import api  # type: ignore
 
-        return {mode: dict(keys) for mode, keys in api.keybindings.items()}  # type: ignore
+        return {
+            mode: dict(keys) for mode, keys in api.keybindings.items()
+        }  # type: ignore
 
     def parse(self, fetched: HotkeysWithModes) -> HotkeysWithModes:
         return fetched
